import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

public class TJTextArea extends JFrame {
    // 1. Declare the references for the following objects.
    Container container;
    JLabel label = null;
    JTextField textField = null;
    JTextArea textArea = null;
    JButton insertButton = null;
    JButton deleteButton = null;
    JButton cutButton = null;
    JButton copyButton = null;
    JButton pasteButton = null;

    public TJTextArea() {
        // 2. Assign a name to the frame and obtain a handle
        // on the frame's content pane.
        super("TJTextArea");
        container = this.getContentPane();

        // 3. Create the fonts for label and text area.
        Font labelFont = new Font("SanSerif", Font.BOLD, 14);
        Font textFont = new Font("Dialog", Font.PLAIN, 12);

        // 4. Use the gridbag layout for the applet.
        GridBagLayout gridbag = new GridBagLayout();
        container.setLayout(gridbag);
        GridBagConstraints c = new GridBagConstraints();

        // 5. Add a label.
        c.fill = c.BOTH;
        c.insets = new Insets(2,2,2,2);
        c.gridx = 0; c.gridy = 0;
        c.gridwidth = 5; c.gridheight = 1;
        c.anchor = c.WEST;
        c.weightx = 1.0; c.weighty = 1.0;
        label = new JLabel("Enter Text: ");
        label.setFont(labelFont);
        gridbag.setConstraints(label, c);
        container.add(label);  // add the label

        // 6. Add a text field.
        c.anchor = c.CENTER;
        c.gridx = 0; c.gridy = 1;
        textField = new JTextField();
        gridbag.setConstraints(textField, c);
        container.add(textField);  // add the text-field

        // 7. Add the Insert button.
        c.gridx = 0; c.gridy = 2;
        c.gridwidth = 1; c.gridheight = 1;
        c.fill = c.BOTH;
        insertButton = new JButton("Insert");
        insertButton.setBackground(Color.lightGray);
        gridbag.setConstraints(insertButton, c);
        container.add(insertButton);  // add insert button
        ButtonListener inButtonListener = new ButtonListener();
        insertButton.addActionListener(inButtonListener);

        // 8. Add the Delete button.
        c.gridx = 1; c.gridy = 2;
        deleteButton = new JButton("Delete");
        deleteButton.setBackground(Color.lightGray);
        gridbag.setConstraints(deleteButton, c);
        container.add(deleteButton); // add the delete button
        ButtonListener dlButtonListener = new ButtonListener();
        deleteButton.addActionListener(dlButtonListener);

        // 9. Add the Cut button.
        c.gridx = 2; c.gridy = 2;
        cutButton = new JButton("Cut");
        cutButton.setBackground(Color.lightGray);
        gridbag.setConstraints(cutButton, c);
        container.add(cutButton); // add the cut button
        ButtonListener ctButtonListener = new ButtonListener();
        cutButton.addActionListener(ctButtonListener);

        // 10. Add the Copy button.
        c.gridx = 3; c.gridy = 2;
        copyButton = new JButton("Copy");
        copyButton.setBackground(Color.lightGray);
        gridbag.setConstraints(copyButton, c);
        container.add(copyButton); // add the copy button
        ButtonListener cpButtonListener = new ButtonListener();
        copyButton.addActionListener(cpButtonListener);

        // 11. Add the Paste button.
        c.gridx = 4; c.gridy = 2;
        pasteButton = new JButton("Paste");
        pasteButton.setBackground(Color.lightGray);
        gridbag.setConstraints(pasteButton, c);
        container.add(pasteButton); // add the paste button
        ButtonListener psButtonListener = new ButtonListener();
        pasteButton.addActionListener(psButtonListener);

        // 12. Add the text area.
        c.gridx = 0; c.gridy = 3;
        c.gridwidth = 5; c.gridheight = 1;
        c.weightx = 1.0; c.weighty = 1.0;
        c.anchor = c.CENTER;
        c.fill = c.BOTH;
        String someText = "The Swing 'JTextArea' is a " +
                          "light-weight component.";
        textArea = new JTextArea(someText, // To be displayed initially
                                 6, // Number of rows.
                                 30); // Number of columns.
        textArea.setFont(textFont);
        textArea.setBackground(Color.white);
        textArea.setSelectionColor(Color.yellow);
        textArea.setTabSize(5); // The tab size.
        textArea.setLineWrap(true); // Wrap the line at the container end.
        gridbag.setConstraints(textArea, c);
        container.add(textArea); // Add the text area.

        // 13. Add the window listener to close the frame
        // and display it with the specified size.
        addWindowListener(new WindowEventHandler());
        setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
        setSize(400, 200); // width=400, height=200
        show(); // Display the frame.
    }

    // 14. Button listener class.
    class ButtonListener implements ActionListener {
        public void actionPerformed(ActionEvent e) {
            JButton b = (JButton) e.getSource();
            if (b == insertButton) {
                try {
                    // Insert text at the caret position. The text is
                    // is retrieved from the text field by using getText().
                    textArea.insert(textField.getText(),
                                    textArea.getCaretPosition());
                }
                catch (IllegalArgumentException excep) {
                }
            }
            else if (b == deleteButton) {
                textArea.replaceSelection(""); // Selected text is deleted.
            }
            else if (b == cutButton) {
                textArea.cut(); // Cut operation.
            }
            else if (b == copyButton) {
                textArea.copy(); // Copy operation.
            }
            else if (b == pasteButton) {
                textArea.paste(); // Paste operation.
            }
        }
    }

    // 15. The listener class to handle closing of the frame.
    class WindowEventHandler extends WindowAdapter {
        public void windowClosing(WindowEvent evt) {
            System.exit(0);
        }
    }

    // 16. The main method.
    public static void main(String[] args){
        new TJTextArea();
    }
}

