import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import java.applet.*;

public class TJToggleButton extends JApplet {
    // 1. Declare a couple of toggle button references.
    JToggleButton playButton,stopButton;
    // 2. Audio support.
    AudioClip audioClip = null;

    // 3.Icons to be used for the Stop button.
    Icon enabledIcon = new TestIcon(Color.red);
    Icon disabledIcon = new TestIcon(Color.gray);
    String LF = "com.sun.java.swing.plaf.motif.MotifLookAndFeel";

    public void init() {
        // 4. Sets the Motif look-and-feel.
        try {
            UIManager.setLookAndFeel(LF);
        } catch (Exception e) {
            System.err.println("Look and Feel not Initialized!");
        }

        // 5. Create and set the layout.
        GridLayout grid = new GridLayout(1,2);
        this.getContentPane().setLayout(grid);
        this.getContentPane().setBackground(Color.gray);

        // 6. Create and add a Play button.
        ImageIcon playIcon = new ImageIcon("play.gif");
        playButton = new JToggleButton("Play",playIcon);
        playButton.setBackground(Color.lightGray);
        playButton.setForeground(Color.blue);
        playButton.setMnemonic('p');
        CustomListener cl = new CustomListener();
        playButton.addActionListener(cl);
        this.getContentPane().add(playButton);

        // 7. Create and add a Stop button.
        stopButton = new JToggleButton("Stop",enabledIcon);
        stopButton.setVerticalTextPosition(SwingConstants.BOTTOM);
        stopButton.setHorizontalTextPosition(SwingConstants.CENTER);
        stopButton.setBackground(Color.lightGray);
        stopButton.setForeground(Color.blue);
        stopButton.setMnemonic('s');
        stopButton.addActionListener(cl);
        this.getContentPane().add(stopButton);

        // 8. Initialize the audio clip.
        if (audioClip == null) {
            audioClip = this.getAudioClip(getCodeBase(),
                        "music.au");
        }
    }
    // 9. Listener class for the button objects.
    class CustomListener implements ActionListener {
        public void actionPerformed(ActionEvent e) {
            JToggleButton button = (JToggleButton) e.getSource();
            // 10. If the play button is clicked
            if (button == playButton) {
                playButton.setEnabled(false);
                if (!stopButton.isEnabled())
                    stopButton.setEnabled(true);
                stopButton.setIcon(enabledIcon);
                audioClip.loop();
            }
            // 11. If the stop button is clicked
            else if (button == stopButton) {
                stopButton.setEnabled(false);
                stopButton.setIcon(disabledIcon);
                if (!playButton.isEnabled())
                    playButton.setEnabled(true);
                audioClip.stop();
            }
        }
    }
}

/*
 * 12. A class that implements the Icon interface;
 * a slight modification (to display the specified
 * colors) of the TestIcon shown in chapter-7.
 */

class TestIcon implements Icon {
    int width = 20; // default icon-width
    int height = 20;  // default icon-height
    Color fillColor;  // icon color to be specified

    // 13. Constructor that specifies the icon color.
    public TestIcon(Color fillColor) {
        this.fillColor = fillColor;
    }

    // 14. Interface method to paint the icon.
    // using the methods in graphics context object
    public void paintIcon(Component c,
                          Graphics g,
                          int x,
                          int y) {
        g.setColor(fillColor);
        g.fillOval(x, y, width, height);
        g.setColor(Color.black);
        g.drawOval(x, y, width, height);
    }

    // 15. Interface method to retrieve the icon width.
    public int getIconWidth() {
        return width;
    }

    // 16. Interface method to retrieve the icon height.
    public int getIconHeight() {
        return height;
    }
}
